import { Server } from "socket.io";
import {TSocket} from "../../utilities/Types";
import {writeFile} from "node:fs";
import {randomUUID} from "node:crypto";
import path from "path";
import fs from "fs";


interface IPayload {
}

/**
 * Handle game master upload tile event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:tile:upload', async (data: any, callback: (response: boolean) => void) => {

        if (socket.character?.role !== 'gm') {
            return;
        }

        // get root path
        const public_folder = path.join(process.cwd(), 'public', 'tiles');
        
        // check if folder exists or create it
        if (!fs.existsSync(public_folder)) {
            fs.mkdirSync(public_folder, { recursive: true });
        }

        for (const key in data) {
            // the files in the folder are named 0.png, 1.png, 2.png etc... check the last file name and add 1
            const files = fs.readdirSync(public_folder);
            const lastFile = files.reduce((a, b) => a > b ? a : b, '0.png');
            const lastFileName = lastFile?.split('.')[0];
            const filename = `${parseInt(lastFileName ?? '0') + 1}.png`;
            const finalFilePath = path.join(public_folder, filename);
            const tile = data[key];

            // save the tile to the disk, for example
            writeFile(finalFilePath, tile, (err) => {});

            // return true to the client
            callback(true);
        }
    });
}